@@ -92,3 +92,5 @@ LDP_RDF_CONTEXT={
    }
 }
 SEND_BACKLINKS=False
+GUARDIAN_AUTO_PREFETCH = True
+PERMISSIONS_CACHE = True
