@@ -52,9 +52,14 @@ class TestsInbox(APITestCase):
         self.assertEquals(len(activities), activity_len)
         self.assertIn(response["Location"], activities.values_list('urlid', flat=True))
 
+    def _assert_follower_created(self, local_urlid, external_urlid):
+        existing_followers = Follower.objects.filter(object=local_urlid).values_list('follower', flat=True)
+        self.assertTrue(external_urlid in existing_followers)
+
     #
     #   CREATE ACTIVITY
     #
+    @override_settings(SEND_BACKLINKS=True, DISABLE_OUTBOX=True)
     def test_create_activity_circle(self):
         obj = {
             "@type": "hd:circle",
@@ -77,6 +82,10 @@ class TestsInbox(APITestCase):
         self.assertEqual(circles[0].owner, self.user)
         self._assert_activity_created(response)
 
+        # assert external circle member now following local user
+        self.assertEquals(Follower.objects.count(), 1)
+        self._assert_follower_created(self.user.urlid, "https://distant.com/circles/1/")
+
     # sender has sent a circle with a local user that doesn't exist
     def test_create_activity_circle_local(self):
         urlid = '{}{}'.format(settings.SITE_URL, 'someonewhodoesntexist')
@@ -104,6 +113,7 @@ class TestsInbox(APITestCase):
     #   ADD ACTIVITIES
     #
     # project model has a direct many-to-many with User
+    @override_settings(SEND_BACKLINKS=True, DISABLE_OUTBOX=True)
     def test_add_activity_project(self):
         obj = {
             "@type": "hd:project",
@@ -124,18 +134,26 @@ class TestsInbox(APITestCase):
         self.assertIn("https://distant.com/projects/1/", user_projects.values_list('urlid', flat=True))
         self._assert_activity_created(response)
 
+        # assert external circle member now following local user
+        self.assertEquals(Follower.objects.count(), 1)
+        self._assert_follower_created(self.user.urlid, "https://distant.com/projects/1/")
+
     # circle model has a many-to-many with user, through an intermediate model
+    @override_settings(SEND_BACKLINKS=True, DISABLE_OUTBOX=True)
     def test_add_activity_circle(self):
+        ext_circlemember_urlid = "https://distant.com/circle-members/1/"
+        ext_circle_urlid = "https://distant.com/circles/1/"
+
         obj = {
             "@type": "hd:circlemember",
-            "@id": "https://distant.com/circle-members/1/",
+            "@id": ext_circlemember_urlid,
             "user": {
               "@type": "foaf:user",
               "@id": self.user.urlid
             },
             "circle": {
                 "@type": "hd:circle",
-                "@id": "https://distant.com/circles/1/"
+                "@id": ext_circle_urlid
             }
         }
         payload = self._get_activity_request_template("Add", obj, self._build_target_from_user(self.user))
@@ -149,15 +167,19 @@ class TestsInbox(APITestCase):
         user_circles = self.user.circles.all()
         self.assertEquals(len(circles), 1)
         self.assertEquals(len(user_circles), 1)
-        self.assertIn("https://distant.com/circles/1/", circles.values_list('urlid', flat=True))
-        self.assertIn("https://distant.com/circle-members/1/", user_circles.values_list('urlid', flat=True))
+        self.assertIn(ext_circle_urlid, circles.values_list('urlid', flat=True))
+        self.assertIn(ext_circlemember_urlid, user_circles.values_list('urlid', flat=True))
         self._assert_activity_created(response)
 
+        # assert external circle member now following local user
+        self.assertEquals(Follower.objects.count(), 1)
+        self._assert_follower_created(self.user.urlid, ext_circlemember_urlid)
+
     # test sending an add activity when the backlink already exists
     @override_settings(SEND_BACKLINKS=True, DISABLE_OUTBOX=True)
     def test_add_activity_object_already_added(self):
         circle = Circle.objects.create(urlid="https://distant.com/circles/1/")
-        CircleMember.objects.create(urlid="https://distant.com/circle-members/1/", circle=circle, user=self.user)
+        cm = CircleMember.objects.create(urlid="https://distant.com/circle-members/1/", circle=circle, user=self.user)
 
         obj = {
             "@type": "hd:circlemember",
@@ -189,6 +211,10 @@ class TestsInbox(APITestCase):
         self._assert_activity_created(response)
         self.assertEqual(Activity.objects.count(), prior_count + 1)
 
+        # assert that followers exist for the external urlids
+        self.assertEquals(Follower.objects.count(), 1)
+        self._assert_follower_created(self.user.urlid, cm.urlid)
+
     # TODO: https://git.startinblox.com/djangoldp-packages/djangoldp/issues/250
     def test_add_activity_str_parameter(self):
         payload = self._get_activity_request_template("Add", "https://distant.com/somethingunknown/1/",
@@ -280,9 +306,13 @@ class TestsInbox(APITestCase):
     #   REMOVE & DELETE ACTIVITIES
     #
     # project model has a direct many-to-many with User
+    @override_settings(SEND_BACKLINKS=True, DISABLE_OUTBOX=True)
     def test_remove_activity_project_using_origin(self):
         project = Project.objects.create(urlid="https://distant.com/projects/1/")
         self.user.projects.add(project)
+        Follower.objects.create(object=self.user.urlid, inbox='https://distant.com/inbox/',
+                                follower=project.urlid, is_backlink=True)
+        prior_activity_count = Activity.objects.count()
 
         obj = {
             "@type": "hd:project",
@@ -300,7 +330,8 @@ class TestsInbox(APITestCase):
         self.assertEquals(len(projects), 1)
         self.assertEquals(len(user_projects), 0)
         self.assertIn("https://distant.com/projects/1/", projects.values_list('urlid', flat=True))
-        self._assert_activity_created(response)
+        self._assert_activity_created(response, prior_activity_count + 2)
+        self.assertEqual(Follower.objects.count(), 0)
 
     # TODO: test_remove_activity_project_using_target
 
@@ -348,9 +379,12 @@ class TestsInbox(APITestCase):
         self.assertEqual(Activity.objects.all().count(), prior_count + 1)
 
     # Delete CircleMember
+    @override_settings(SEND_BACKLINKS=True, DISABLE_OUTBOX=True)
     def test_delete_activity_circle_using_origin(self):
         circle = Circle.objects.create(urlid="https://distant.com/circles/1/", allow_create_backlink=False)
-        CircleMember.objects.create(urlid="https://distant.com/circle-members/1/",circle=circle, user=self.user)
+        cm = CircleMember.objects.create(urlid="https://distant.com/circle-members/1/",circle=circle, user=self.user)
+        Follower.objects.create(object=self.user.urlid, inbox='https://distant.com/inbox/',
+                                follower=cm.urlid, is_backlink=True)
 
         obj = {
             "@type": "hd:circlemember",
@@ -374,9 +408,11 @@ class TestsInbox(APITestCase):
         circles = Circle.objects.all()
         user_circles = self.user.circles.all()
         self.assertEquals(len(circles), 1)
+        self.assertEquals(CircleMember.objects.count(), 0)
         self.assertEquals(len(user_circles), 0)
         self.assertIn("https://distant.com/circles/1/", circles.values_list('urlid', flat=True))
         self._assert_activity_created(response)
+        self.assertEqual(Follower.objects.count(), 0)
 
     # TODO: test_delete_activity_circle_using_target
 
